/**
 * Routes for the Vue router.
 *
 * Part of the basebox sample TODO app.
 * https://basebox.tech
 */

import {loggedIn, showError, store} from "../store";
import { createRouter, createWebHistory } from 'vue-router'
import HomeView from '../views/HomeView.vue'
import { objectToQueryString } from "../util/net";
import {oauthCallbackHandler} from "../util/oauth";
import {storeInit} from "../store";

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      name: 'home',
      component: HomeView
    },
    {
      path: '/about',
      name: 'about',
      // route level code-splitting
      // this generates a separate chunk (About.[hash].js) for this route
      // which is lazy-loaded when the route is visited.
      component: () => import('../views/AboutView.vue')
    },
    {
      path: '/lists',
      name: 'lists',
      component: () => import('../components/Lists.vue')
    },
  ]
})

router.beforeEach(async (to, from) => {

  // Handle OAuth callback request.
  // This request is coming in after the user entered her/his credentials at the IdP
  // login form; the IdP (e.g. Keycloak) redirects the browser to the URL of this route.
  if (to.path.startsWith("/oauth-callback")) {
    let queryString = objectToQueryString(to.query);
    console.info(`Got /oauth-callback with query string '${queryString}`);

    /* Pass the query string to the handler function */
    try {
      await oauthCallbackHandler(queryString);
    } catch (err) {
      const errorMsg = `Failed to get session info from basebox/finish OpenID Connect login:  ${err}`;
      console.error(errorMsg);
      /* show error */
      showError(errorMsg);
    }

    return {name: 'home'};
  }

  /* if no user is logged in, we redirect to the home page */
  if (!loggedIn() && to.path.length > 1 && to.path !== "/about") {
    return {name: 'home'};
  }

});

export default router
